.. image:: https://raw.githubusercontent.com/PBLab/python-pysight/master/docs/pysight_logo.png
   :scale: 1
   :alt: PySight
.. start-badges

.. list-table::
    :stub-columns: 1
    :align: center

    * - docs
      - |docs| |gitter|
    * - tests
      - | |azure|
    * - package
      - | |version| |wheel| |supported_versions|
        | |supported_implementations| |codestyle|

.. |docs| image:: https://readthedocs.org/projects/python-pysight/badge/?style=flat
    :target: https://readthedocs.org/projects/python-pysight
    :alt: Documentation Status

.. |gitter| image:: https://badges.gitter.im/python-pysight/gitter.png
    :target: https://gitter.im/python-pysight/Lobby
    :alt: Gitter Chat

.. |azure| image:: https://dev.azure.com/pblabgeneral/pysight/_apis/build/status/PBLab.python-pysight?branchName=master
    :alt: Azure Pipelines Build Status
    :target: https://dev.azure.com/pblabgeneral/pysight/_build/latest?definitionId=1&branchName=master

.. |version| image:: https://img.shields.io/pypi/v/pysight.svg
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/pysight

.. |wheel| image:: https://img.shields.io/pypi/wheel/pysight.svg
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/pysight

.. |supported_versions| image:: https://img.shields.io/pypi/pyversions/pysight.svg
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/pysight

.. |supported_implementations| image:: https://img.shields.io/pypi/implementation/pysight.svg
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/pysight

.. |codestyle| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :alt: Code style
    :target: https://github.com/ambv/black

.. end-badges

Create images and volumes from photon lists generated by a multiscaler.
Examples can be found in the ``examples`` folder.

* Free software: Creative Commons

* Created in `Pablo Blinder's Lab <http://pblab.tau.ac.il/en/>`_.


Installation and Documentation
==============================

``pip install pysight``

Current version: 0.11.0

Please refer to the `official documentation <https://python-pysight.readthedocs.io/>`_ for detailed usage instructions.

If you have questions, come visit us at our `Gitter channel <https://gitter.im/python-pysight/Lobby>`_ or use GitHub's
issue tracker.


References
==========

PySight is fully described in `this Optica article <https://www.osapublishing.org/optica/abstract.cfm?uri=optica-5-9-1104>`_,
released in September 2018.

Project Status
==============

PySight is currently in maintenance mode. The application is working well and
should be usable for new users. However, new features are unlikely to be added,
and activity in the repo will probably be mainly limited to bug fixes and some
documentation improvements.
